.TH LPD 1 "Jul 2002" Linux "User Manuals"
.SH NAME
lpd \- Line printer daemon
.SH SYNOPSIS
.B lpd
.SH DESCRIPTION
This is a Perl replacement for the ancient BSD line printer daemon and
forms part of the "Coherent printing system". This daemon
controls access to the various physical printers on a system by
spawning a child for each such printer. In addition printers which
have several modes of operation, for example most inkjets which can
operate in colour, black and white, draft, photo-quality etc., can be
set up as any number of "virtual printers". This allows a coherent
queue control to such printers.

.B lpd
only needs to run on the actual print spooler machine, it does
\fBnot\fR need to run on the various clients and therefor these
clients also do not need \fBfoomatic\fR or printer drivers for the
printer(s) being used.

.SS Printer Banks
A virtual printer may consist of a bank of identical
(only) printers which share the printing duties of their print
queue. A bank of printers may appear as several different virtual
printers but must always appear together in all such virtual printer
configurations. In other words, printers used in a bank must always be
used in a bank.

.SS Input
The basic assumption of the printing system is that all jobs come to
the print queue in the form of plain text, PostScript, or \fIraw\fR
(ie pre-converted for the printer, for example the normal output of
\fBGimp-Print\fR) data. This assumption greatly simplifies life by
placing the onus on printing applications to produce one of the
required formats. In practice this generally means PostScript and
almost all programs can generate decent PostScript output.

.SS Requirements
.B lpd
depends on the use of the
.B foomatic
printer database system and also on the existence of the correct
driver(s) for your printer being available on the print host, unless
all jobs are being sent as \fIraw\fR data.


.SH OPTIONS
Currently 
.B lpd 
takes no options, but see also 
.B DIAGNOSTICS
below.

.SH FILES
.B lpd
uses several files and directories. In some cases these will be named
after the physical printer being used. The printer names can be
anything you like although it's worth bearing in mind that the names
will end up as path and file names that might need to be typed at the
console. The names of the physical printers have nothing to do with
the virtual printers. 

So, for example, a good name for a physical printer is \fIoldhp\fR or
\fIhpdj4\fR while good names for the virtual printers are things like
\fIlp\fR, \fIdraft\fR, \fIcolour\fR etc.

.I /etc/foomatic/direct
.RS
This holds the \fI.PPD\fR and \fIfoo\fR files from
\fBfoomatic\fR. There should be one of each of these files for each
physical printer \fItype\fR connected to the spooler, ie if you have
two Epson Stylus Photo 810's and a Linotronic 500 you need a single
\fIepson.foo\fR and a single \fIlino.foo\fR file (the names are
arbitrary).

.RE
.I /var/spool/lpd/<printername>
.RS
One such directory is needed for each bank of physical printers (which
may be one printer) and the name of the directory is what defines the
physical name of that printer bank. Remember that a bank of printers
must always be used together.

Within each spool directory there should be a link called
\fI<printername>.foo\fR to the .foo file described above in the
\fI/etc/foomatic/direct\fR directory. 

Also found within this spool directory will be the \fIoption\fR files
which define which \fBfoomatic\fR options are used when using a
virtual printer. These files named after the virtual printer suffixed
by \fI.options\fR.

.SH "EXAMPLE CONFIG"
The system mentioned above with two Epsons and a
Linotronic will have a .foo file for each type of printer in the
\fI/etc/foomatic/direct\fR directory. 

If we assume that the printers are called "epson1", "epson2" and
"lino" and that the Epsons will be driven in three modes: "draft",
"colour", and "top" (for "top quality" mode) then the other files are
quite simple:

.SS "Individual Printers"
Assuming that the Epson printers are not to be collected into a bank,
there will be a directory for each physical printer: 

.I /var/spool/epson1

.I /var/spool/epson2

.I /var/spool/lino

Each of the Epson spool directories will contain the four files:

\fIepson.foo\fR
.RS 
A link to the file \fI/etc/foomatic/direct/epson.foo\fR.
.RE

\fIdraft.options\fR,

\fIcolour.options\fR,

\fItop.options\fR,

As an example of what is in the option files, the content of
\fItop.options\fR would probably something look like this:

.nf
.sp
.ft CW
PageSize=A4
Quality=2880x720sw
GSResolution=2880x720DPI
ImageType=Photographs
OutputType=Color 
MediaType=Photo
.sp
.fi

\fR
The lino directory would contain:

.IP \fIlino.foo\fR
A  link to the file \fI/etc/foomatic/direct/lino.foo\fR,
.IP \fItop.options\fR
Since the Lino is normally going to be used in its default mode
top.options may be empty.

.RE
The printcap for this configurations would look something like this:

.nf
.sp
.ft CW
lp|draft:\\
        :sd=/var/spool/epson1:\\
        :lp=/dev/lp0:

colour:\\
        :sd=/var/spool/epson2:\\
        :lp=/dev/usb/lp0:

top:\\
        :sd=/var/spool/lino:\\
        :lp=/dev/usb/lp1:
.sp
.fi

.SS "Banked Config"
If we want to use the two epsons as a bank of printers (the Lino can't
combine since it uses a different driver) which can be
addressed as "draft" and "colour" then we only need to change the
printcap file as follows:

.nf
.sp
.ft CW
lp|draft:\\
        :sd=/var/spool/epson1:\\
        :lp=/dev/lp0:\\
        :lp=/dev/usb/lp0

colour:\\
        :sd=/var/spool/epson2:\\
        :lp=/dev/lp0:\\
        :lp=/dev/usb/lp0:

top:\\
        :sd=/var/spool/lino:\\
        :lp=/dev/usb/lp1:
.sp
.fi

.RE
\fRThis will allow jobs to be sent to "draft" or "colour" and be picked
up by the first Epson which becomes available (subject to queuing, of course).

.SS GETTING THE FOO, PPD AND MANUAL
If you have installed \fBfoomatic\fR then the command 

\fIfoomatic-datafile -t direct -d gimp-print -p Epson-Stylus_Photo_1290 >
epson.foo\fR

will generate, in this case, a .foo file for an Epson Stylus Photo 1290,
and 

\fIfoomatic-datafile -t ppd -d gimp-print -p Epson-Stylus_Photo_1290 >
epson.ppd\fR

Will produce the .ppd file (which can be used with programs like
StarOffice or fed into the Adobe generic PostScript driver under
Windows to allow the printer to be driven to its full potential).
Once you have these, edit the .foo file and set the active "$postpipe"
line to read

\fI$postpipe="| cat >$LPDDEV";\fR

To find out what options you printer supports in its \fI.options\fR
file type

\fILPDDEV='/dev/lp';echo "" | directomatic -P epson -o docs\fR

after installing lpd.

.SH FILES
.I "/etc/printcap"
.RS
A set of printer descriptions separated by blank lines. The format of
each printer description is:

.RE
.nf
.sp
.ft CW
<PrinterBankName>[|<alternative name>...]:[<property name>=<value>:]+
.sp
.fi

\fRA description may be split over more than one line by ending each
split line in "\\".

The property names currently understood are:

.IP sd 
The spool directory for this bank.

.IP lp 
The device or script to which output is to be sent, eg, \fI/dev/printer\fR.

.IP rm
The name of a remote host to send the job to instead of the local
machine. This overrides the previous two options if they are present
too.

.IP rp
The name of the printer bank on a remote machine. Ignored unless the
previous option also appears.

.IP fake
Used as \fIfake=true\fR to indicate that the "lp" option is actually
pointing to something other than a physical device, such as when Samba
is being used to spool out to a Windows host. 

This prevents the daemon from testing the availability of the device
which is meaningless when applied to normal files.
.RE

.I /etc/hosts.lpd
.RS
A whitespace-delimited list of all hosts allows to access the lpd
daemon running on this machine. If this file does not exist then all
machines that can make a connection to it may print (in which case it
had better be behind a firewall).

Use fully-qualified names such as .fIalpha.localdomain\fR.

.SH DIAGNOSTICS
The program (which is a Perl script) has the line \fI$debug=0\fR near
the top. If this is set to 1 a \fBlarge\fR amount of diagnostic
information will be spat out, including the conversations between the
server and the various clients.

.SH BUGS
None actually known at the moment. This manual page, on the other hand,
is deficient in several ways such as not explaining the actual spooled
files' formats. Next release.

One limitation that is important is that when a job is cancelled while
actually printing the printer is left is an undefined state which
normally requires it to be turned off and on again. I don't hold out
much chance that this will ever be fixed unless the foomatic
developers find some way to define reset codes in their database.

.SH AUTHOR
Thomas Worthington (tww@tww.cx) 2002

.SH "SEE ALSO"
.BR lpr (1),
.BR lpq (1),
.BR lprm (1),
.BR foomatic-configure (1),
.BR foomatic-datafile (1)